package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmReportPlanDay;

/**
 * 工作计划日统计Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-28
 */
public interface PdmReportPlanDayMapper
{
    /**
     * 查询工作计划日统计
     *
     * @param id 工作计划日统计主键
     * @return 工作计划日统计
     */
    public PdmReportPlanDay selectPdmReportPlanDayById(Long id);

    /**
     * 查询工作计划日统计列表
     *
     * @param pdmReportPlanDay 工作计划日统计
     * @return 工作计划日统计集合
     */
    public List<PdmReportPlanDay> selectPdmReportPlanDayList(PdmReportPlanDay pdmReportPlanDay);

    /**
     * 新增工作计划日统计
     *
     * @param pdmReportPlanDay 工作计划日统计
     * @return 结果
     */
    public int insertPdmReportPlanDay(PdmReportPlanDay pdmReportPlanDay);

    /**
     * 修改工作计划日统计
     *
     * @param pdmReportPlanDay 工作计划日统计
     * @return 结果
     */
    public int updatePdmReportPlanDay(PdmReportPlanDay pdmReportPlanDay);

    /**
     * 删除工作计划日统计
     *
     * @param id 工作计划日统计主键
     * @return 结果
     */
    public int deletePdmReportPlanDayById(Long id);

    /**
     * 批量删除工作计划日统计
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmReportPlanDayByIds(Long[] ids);
}
